# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/core/v3/config_source.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from xds.core.v3 import authority_pb2 as xds_dot_core_dot_v3_dot_authority__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/core/v3/config_source.proto',
  package='envoy.config.core.v3',
  syntax='proto3',
  serialized_options=b'\n\"io.envoyproxy.envoy.config.core.v3B\021ConfigSourceProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(envoy/config/core/v3/config_source.proto\x12\x14\x65nvoy.config.core.v3\x1a\'envoy/config/core/v3/grpc_service.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bxds/core/v3/authority.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x95\x05\n\x0f\x41piConfigSource\x12I\n\x08\x61pi_type\x18\x01 \x01(\x0e\x32-.envoy.config.core.v3.ApiConfigSource.ApiTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12I\n\x15transport_api_version\x18\x08 \x01(\x0e\x32 .envoy.config.core.v3.ApiVersionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x15\n\rcluster_names\x18\x02 \x03(\t\x12\x38\n\rgrpc_services\x18\x04 \x03(\x0b\x32!.envoy.config.core.v3.GrpcService\x12\x30\n\rrefresh_delay\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12<\n\x0frequest_timeout\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x44\n\x13rate_limit_settings\x18\x06 \x01(\x0b\x32\'.envoy.config.core.v3.RateLimitSettings\x12&\n\x1eset_node_on_first_message_only\x18\x07 \x01(\x08\"\x92\x01\n\x07\x41piType\x12\x33\n%DEPRECATED_AND_UNAVAILABLE_DO_NOT_USE\x10\x00\x1a\x08\x08\x01\xa8\xf7\xb4\x8b\x02\x01\x12\x08\n\x04REST\x10\x01\x12\x08\n\x04GRPC\x10\x02\x12\x0e\n\nDELTA_GRPC\x10\x03\x12\x13\n\x0f\x41GGREGATED_GRPC\x10\x05\x12\x19\n\x15\x41GGREGATED_DELTA_GRPC\x10\x06:(\x9a\xc5\x88\x1e#\n!envoy.api.v2.core.ApiConfigSource\"I\n\x16\x41ggregatedConfigSource:/\x9a\xc5\x88\x1e*\n(envoy.api.v2.core.AggregatedConfigSource\"\x88\x01\n\x10SelfConfigSource\x12I\n\x15transport_api_version\x18\x01 \x01(\x0e\x32 .envoy.config.core.v3.ApiVersionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01:)\x9a\xc5\x88\x1e$\n\"envoy.api.v2.core.SelfConfigSource\"\xb2\x01\n\x11RateLimitSettings\x12\x30\n\nmax_tokens\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12?\n\tfill_rate\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0e\xfa\x42\x0b\x12\t!\x00\x00\x00\x00\x00\x00\x00\x00:*\x9a\xc5\x88\x1e%\n#envoy.api.v2.core.RateLimitSettings\"\xcf\x03\n\x0c\x43onfigSource\x12+\n\x0b\x61uthorities\x18\x07 \x03(\x0b\x32\x16.xds.core.v3.Authority\x12\x0e\n\x04path\x18\x01 \x01(\tH\x00\x12\x42\n\x11\x61pi_config_source\x18\x02 \x01(\x0b\x32%.envoy.config.core.v3.ApiConfigSourceH\x00\x12;\n\x03\x61\x64s\x18\x03 \x01(\x0b\x32,.envoy.config.core.v3.AggregatedConfigSourceH\x00\x12\x36\n\x04self\x18\x05 \x01(\x0b\x32&.envoy.config.core.v3.SelfConfigSourceH\x00\x12\x38\n\x15initial_fetch_timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12H\n\x14resource_api_version\x18\x06 \x01(\x0e\x32 .envoy.config.core.v3.ApiVersionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01:%\x9a\xc5\x88\x1e \n\x1e\x65nvoy.api.v2.core.ConfigSourceB\x1e\n\x17\x63onfig_source_specifier\x12\x03\xf8\x42\x01*.\n\nApiVersion\x12\x0c\n\x04\x41UTO\x10\x00\x1a\x02\x08\x01\x12\n\n\x02V2\x10\x01\x1a\x02\x08\x01\x12\x06\n\x02V3\x10\x02\x42\x41\n\"io.envoyproxy.envoy.config.core.v3B\x11\x43onfigSourceProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,xds_dot_core_dot_v3_dot_authority__pb2.DESCRIPTOR,envoy_dot_annotations_dot_deprecation__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])

_APIVERSION = _descriptor.EnumDescriptor(
  name='ApiVersion',
  full_name='envoy.config.core.v3.ApiVersion',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTO', index=0, number=0,
      serialized_options=b'\010\001',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='V2', index=1, number=1,
      serialized_options=b'\010\001',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='V3', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1853,
  serialized_end=1899,
)
_sym_db.RegisterEnumDescriptor(_APIVERSION)

ApiVersion = enum_type_wrapper.EnumTypeWrapper(_APIVERSION)
AUTO = 0
V2 = 1
V3 = 2


_APICONFIGSOURCE_APITYPE = _descriptor.EnumDescriptor(
  name='ApiType',
  full_name='envoy.config.core.v3.ApiConfigSource.ApiType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEPRECATED_AND_UNAVAILABLE_DO_NOT_USE', index=0, number=0,
      serialized_options=b'\010\001\250\367\264\213\002\001',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REST', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRPC', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELTA_GRPC', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AGGREGATED_GRPC', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AGGREGATED_DELTA_GRPC', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=802,
  serialized_end=948,
)
_sym_db.RegisterEnumDescriptor(_APICONFIGSOURCE_APITYPE)


_APICONFIGSOURCE = _descriptor.Descriptor(
  name='ApiConfigSource',
  full_name='envoy.config.core.v3.ApiConfigSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='api_type', full_name='envoy.config.core.v3.ApiConfigSource.api_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transport_api_version', full_name='envoy.config.core.v3.ApiConfigSource.transport_api_version', index=1,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_names', full_name='envoy.config.core.v3.ApiConfigSource.cluster_names', index=2,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grpc_services', full_name='envoy.config.core.v3.ApiConfigSource.grpc_services', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='refresh_delay', full_name='envoy.config.core.v3.ApiConfigSource.refresh_delay', index=4,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_timeout', full_name='envoy.config.core.v3.ApiConfigSource.request_timeout', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rate_limit_settings', full_name='envoy.config.core.v3.ApiConfigSource.rate_limit_settings', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_node_on_first_message_only', full_name='envoy.config.core.v3.ApiConfigSource.set_node_on_first_message_only', index=7,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _APICONFIGSOURCE_APITYPE,
  ],
  serialized_options=b'\232\305\210\036#\n!envoy.api.v2.core.ApiConfigSource',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=329,
  serialized_end=990,
)


_AGGREGATEDCONFIGSOURCE = _descriptor.Descriptor(
  name='AggregatedConfigSource',
  full_name='envoy.config.core.v3.AggregatedConfigSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036*\n(envoy.api.v2.core.AggregatedConfigSource',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=992,
  serialized_end=1065,
)


_SELFCONFIGSOURCE = _descriptor.Descriptor(
  name='SelfConfigSource',
  full_name='envoy.config.core.v3.SelfConfigSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transport_api_version', full_name='envoy.config.core.v3.SelfConfigSource.transport_api_version', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036$\n\"envoy.api.v2.core.SelfConfigSource',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1068,
  serialized_end=1204,
)


_RATELIMITSETTINGS = _descriptor.Descriptor(
  name='RateLimitSettings',
  full_name='envoy.config.core.v3.RateLimitSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_tokens', full_name='envoy.config.core.v3.RateLimitSettings.max_tokens', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fill_rate', full_name='envoy.config.core.v3.RateLimitSettings.fill_rate', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\013\022\t!\000\000\000\000\000\000\000\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036%\n#envoy.api.v2.core.RateLimitSettings',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1207,
  serialized_end=1385,
)


_CONFIGSOURCE = _descriptor.Descriptor(
  name='ConfigSource',
  full_name='envoy.config.core.v3.ConfigSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='authorities', full_name='envoy.config.core.v3.ConfigSource.authorities', index=0,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='envoy.config.core.v3.ConfigSource.path', index=1,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='api_config_source', full_name='envoy.config.core.v3.ConfigSource.api_config_source', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ads', full_name='envoy.config.core.v3.ConfigSource.ads', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='self', full_name='envoy.config.core.v3.ConfigSource.self', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_fetch_timeout', full_name='envoy.config.core.v3.ConfigSource.initial_fetch_timeout', index=5,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_api_version', full_name='envoy.config.core.v3.ConfigSource.resource_api_version', index=6,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036 \n\036envoy.api.v2.core.ConfigSource',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_source_specifier', full_name='envoy.config.core.v3.ConfigSource.config_source_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1388,
  serialized_end=1851,
)

_APICONFIGSOURCE.fields_by_name['api_type'].enum_type = _APICONFIGSOURCE_APITYPE
_APICONFIGSOURCE.fields_by_name['transport_api_version'].enum_type = _APIVERSION
_APICONFIGSOURCE.fields_by_name['grpc_services'].message_type = envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2._GRPCSERVICE
_APICONFIGSOURCE.fields_by_name['refresh_delay'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_APICONFIGSOURCE.fields_by_name['request_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_APICONFIGSOURCE.fields_by_name['rate_limit_settings'].message_type = _RATELIMITSETTINGS
_APICONFIGSOURCE_APITYPE.containing_type = _APICONFIGSOURCE
_SELFCONFIGSOURCE.fields_by_name['transport_api_version'].enum_type = _APIVERSION
_RATELIMITSETTINGS.fields_by_name['max_tokens'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_RATELIMITSETTINGS.fields_by_name['fill_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_CONFIGSOURCE.fields_by_name['authorities'].message_type = xds_dot_core_dot_v3_dot_authority__pb2._AUTHORITY
_CONFIGSOURCE.fields_by_name['api_config_source'].message_type = _APICONFIGSOURCE
_CONFIGSOURCE.fields_by_name['ads'].message_type = _AGGREGATEDCONFIGSOURCE
_CONFIGSOURCE.fields_by_name['self'].message_type = _SELFCONFIGSOURCE
_CONFIGSOURCE.fields_by_name['initial_fetch_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CONFIGSOURCE.fields_by_name['resource_api_version'].enum_type = _APIVERSION
_CONFIGSOURCE.oneofs_by_name['config_source_specifier'].fields.append(
  _CONFIGSOURCE.fields_by_name['path'])
_CONFIGSOURCE.fields_by_name['path'].containing_oneof = _CONFIGSOURCE.oneofs_by_name['config_source_specifier']
_CONFIGSOURCE.oneofs_by_name['config_source_specifier'].fields.append(
  _CONFIGSOURCE.fields_by_name['api_config_source'])
_CONFIGSOURCE.fields_by_name['api_config_source'].containing_oneof = _CONFIGSOURCE.oneofs_by_name['config_source_specifier']
_CONFIGSOURCE.oneofs_by_name['config_source_specifier'].fields.append(
  _CONFIGSOURCE.fields_by_name['ads'])
_CONFIGSOURCE.fields_by_name['ads'].containing_oneof = _CONFIGSOURCE.oneofs_by_name['config_source_specifier']
_CONFIGSOURCE.oneofs_by_name['config_source_specifier'].fields.append(
  _CONFIGSOURCE.fields_by_name['self'])
_CONFIGSOURCE.fields_by_name['self'].containing_oneof = _CONFIGSOURCE.oneofs_by_name['config_source_specifier']
DESCRIPTOR.message_types_by_name['ApiConfigSource'] = _APICONFIGSOURCE
DESCRIPTOR.message_types_by_name['AggregatedConfigSource'] = _AGGREGATEDCONFIGSOURCE
DESCRIPTOR.message_types_by_name['SelfConfigSource'] = _SELFCONFIGSOURCE
DESCRIPTOR.message_types_by_name['RateLimitSettings'] = _RATELIMITSETTINGS
DESCRIPTOR.message_types_by_name['ConfigSource'] = _CONFIGSOURCE
DESCRIPTOR.enum_types_by_name['ApiVersion'] = _APIVERSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ApiConfigSource = _reflection.GeneratedProtocolMessageType('ApiConfigSource', (_message.Message,), {
  'DESCRIPTOR' : _APICONFIGSOURCE,
  '__module__' : 'envoy.config.core.v3.config_source_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.ApiConfigSource)
  })
_sym_db.RegisterMessage(ApiConfigSource)

AggregatedConfigSource = _reflection.GeneratedProtocolMessageType('AggregatedConfigSource', (_message.Message,), {
  'DESCRIPTOR' : _AGGREGATEDCONFIGSOURCE,
  '__module__' : 'envoy.config.core.v3.config_source_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.AggregatedConfigSource)
  })
_sym_db.RegisterMessage(AggregatedConfigSource)

SelfConfigSource = _reflection.GeneratedProtocolMessageType('SelfConfigSource', (_message.Message,), {
  'DESCRIPTOR' : _SELFCONFIGSOURCE,
  '__module__' : 'envoy.config.core.v3.config_source_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.SelfConfigSource)
  })
_sym_db.RegisterMessage(SelfConfigSource)

RateLimitSettings = _reflection.GeneratedProtocolMessageType('RateLimitSettings', (_message.Message,), {
  'DESCRIPTOR' : _RATELIMITSETTINGS,
  '__module__' : 'envoy.config.core.v3.config_source_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.RateLimitSettings)
  })
_sym_db.RegisterMessage(RateLimitSettings)

ConfigSource = _reflection.GeneratedProtocolMessageType('ConfigSource', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGSOURCE,
  '__module__' : 'envoy.config.core.v3.config_source_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.ConfigSource)
  })
_sym_db.RegisterMessage(ConfigSource)


DESCRIPTOR._options = None
_APIVERSION.values_by_name["AUTO"]._options = None
_APIVERSION.values_by_name["V2"]._options = None
_APICONFIGSOURCE_APITYPE.values_by_name["DEPRECATED_AND_UNAVAILABLE_DO_NOT_USE"]._options = None
_APICONFIGSOURCE.fields_by_name['api_type']._options = None
_APICONFIGSOURCE.fields_by_name['transport_api_version']._options = None
_APICONFIGSOURCE.fields_by_name['request_timeout']._options = None
_APICONFIGSOURCE._options = None
_AGGREGATEDCONFIGSOURCE._options = None
_SELFCONFIGSOURCE.fields_by_name['transport_api_version']._options = None
_SELFCONFIGSOURCE._options = None
_RATELIMITSETTINGS.fields_by_name['fill_rate']._options = None
_RATELIMITSETTINGS._options = None
_CONFIGSOURCE.oneofs_by_name['config_source_specifier']._options = None
_CONFIGSOURCE.fields_by_name['resource_api_version']._options = None
_CONFIGSOURCE._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/health/v3/hds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.cluster.v3 import cluster_pb2 as envoy_dot_config_dot_cluster_dot_v3_dot_cluster__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import health_check_pb2 as envoy_dot_config_dot_core_dot_v3_dot_health__check__pb2
from envoy.config.endpoint.v3 import endpoint_components_pb2 as envoy_dot_config_dot_endpoint_dot_v3_dot_endpoint__components__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/health/v3/hds.proto',
  package='envoy.service.health.v3',
  syntax='proto3',
  serialized_options=b'\n%io.envoyproxy.envoy.service.health.v3B\010HdsProtoP\001\210\001\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!envoy/service/health/v3/hds.proto\x12\x17\x65nvoy.service.health.v3\x1a%envoy/config/cluster/v3/cluster.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\'envoy/config/core/v3/health_check.proto\x1a\x32\x65nvoy/config/endpoint/v3/endpoint_components.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\xb2\x01\n\nCapability\x12L\n\x16health_check_protocols\x18\x01 \x03(\x0e\x32,.envoy.service.health.v3.Capability.Protocol\"(\n\x08Protocol\x12\x08\n\x04HTTP\x10\x00\x12\x07\n\x03TCP\x10\x01\x12\t\n\x05REDIS\x10\x02:,\x9a\xc5\x88\x1e\'\n%envoy.service.discovery.v2.Capability\"\xad\x01\n\x12HealthCheckRequest\x12(\n\x04node\x18\x01 \x01(\x0b\x32\x1a.envoy.config.core.v3.Node\x12\x37\n\ncapability\x18\x02 \x01(\x0b\x32#.envoy.service.health.v3.Capability:4\x9a\xc5\x88\x1e/\n-envoy.service.discovery.v2.HealthCheckRequest\"\xb3\x01\n\x0e\x45ndpointHealth\x12\x34\n\x08\x65ndpoint\x18\x01 \x01(\x0b\x32\".envoy.config.endpoint.v3.Endpoint\x12\x39\n\rhealth_status\x18\x02 \x01(\x0e\x32\".envoy.config.core.v3.HealthStatus:0\x9a\xc5\x88\x1e+\n)envoy.service.discovery.v2.EndpointHealth\"\x8e\x01\n\x17LocalityEndpointsHealth\x12\x30\n\x08locality\x18\x01 \x01(\x0b\x32\x1e.envoy.config.core.v3.Locality\x12\x41\n\x10\x65ndpoints_health\x18\x02 \x03(\x0b\x32\'.envoy.service.health.v3.EndpointHealth\"\x83\x01\n\x16\x43lusterEndpointsHealth\x12\x14\n\x0c\x63luster_name\x18\x01 \x01(\t\x12S\n\x19locality_endpoints_health\x18\x02 \x03(\x0b\x32\x30.envoy.service.health.v3.LocalityEndpointsHealth\"\xec\x01\n\x16\x45ndpointHealthResponse\x12\x45\n\x10\x65ndpoints_health\x18\x01 \x03(\x0b\x32\'.envoy.service.health.v3.EndpointHealthB\x02\x18\x01\x12Q\n\x18\x63luster_endpoints_health\x18\x02 \x03(\x0b\x32/.envoy.service.health.v3.ClusterEndpointsHealth:8\x9a\xc5\x88\x1e\x33\n1envoy.service.discovery.v2.EndpointHealthResponse\"\xac\x02\n*HealthCheckRequestOrEndpointHealthResponse\x12K\n\x14health_check_request\x18\x01 \x01(\x0b\x32+.envoy.service.health.v3.HealthCheckRequestH\x00\x12S\n\x18\x65ndpoint_health_response\x18\x02 \x01(\x0b\x32/.envoy.service.health.v3.EndpointHealthResponseH\x00:L\x9a\xc5\x88\x1eG\nEenvoy.service.discovery.v2.HealthCheckRequestOrEndpointHealthResponseB\x0e\n\x0crequest_type\"\xb1\x01\n\x11LocalityEndpoints\x12\x30\n\x08locality\x18\x01 \x01(\x0b\x32\x1e.envoy.config.core.v3.Locality\x12\x35\n\tendpoints\x18\x02 \x03(\x0b\x32\".envoy.config.endpoint.v3.Endpoint:3\x9a\xc5\x88\x1e.\n,envoy.service.discovery.v2.LocalityEndpoints\"\xbb\x02\n\x12\x43lusterHealthCheck\x12\x14\n\x0c\x63luster_name\x18\x01 \x01(\t\x12\x38\n\rhealth_checks\x18\x02 \x03(\x0b\x32!.envoy.config.core.v3.HealthCheck\x12\x46\n\x12locality_endpoints\x18\x03 \x03(\x0b\x32*.envoy.service.health.v3.LocalityEndpoints\x12W\n\x18transport_socket_matches\x18\x04 \x03(\x0b\x32\x35.envoy.config.cluster.v3.Cluster.TransportSocketMatch:4\x9a\xc5\x88\x1e/\n-envoy.service.discovery.v2.ClusterHealthCheck\"\xc7\x01\n\x14HealthCheckSpecifier\x12J\n\x15\x63luster_health_checks\x18\x01 \x03(\x0b\x32+.envoy.service.health.v3.ClusterHealthCheck\x12+\n\x08interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration:6\x9a\xc5\x88\x1e\x31\n/envoy.service.discovery.v2.HealthCheckSpecifier2\xde\x02\n\x16HealthDiscoveryService\x12\x8d\x01\n\x11StreamHealthCheck\x12\x43.envoy.service.health.v3.HealthCheckRequestOrEndpointHealthResponse\x1a-.envoy.service.health.v3.HealthCheckSpecifier\"\x00(\x01\x30\x01\x12\xb3\x01\n\x10\x46\x65tchHealthCheck\x12\x43.envoy.service.health.v3.HealthCheckRequestOrEndpointHealthResponse\x1a-.envoy.service.health.v3.HealthCheckSpecifier\"+\x82\xd3\xe4\x93\x02\x1c\"\x1a/v3/discovery:health_check\x82\xd3\xe4\x93\x02\x03:\x01*B>\n%io.envoyproxy.envoy.service.health.v3B\x08HdsProtoP\x01\x88\x01\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_cluster_dot_v3_dot_cluster__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v3_dot_health__check__pb2.DESCRIPTOR,envoy_dot_config_dot_endpoint_dot_v3_dot_endpoint__components__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])



_CAPABILITY_PROTOCOL = _descriptor.EnumDescriptor(
  name='Protocol',
  full_name='envoy.service.health.v3.Capability.Protocol',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HTTP', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TCP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REDIS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=448,
  serialized_end=488,
)
_sym_db.RegisterEnumDescriptor(_CAPABILITY_PROTOCOL)


_CAPABILITY = _descriptor.Descriptor(
  name='Capability',
  full_name='envoy.service.health.v3.Capability',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='health_check_protocols', full_name='envoy.service.health.v3.Capability.health_check_protocols', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CAPABILITY_PROTOCOL,
  ],
  serialized_options=b'\232\305\210\036\'\n%envoy.service.discovery.v2.Capability',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=356,
  serialized_end=534,
)


_HEALTHCHECKREQUEST = _descriptor.Descriptor(
  name='HealthCheckRequest',
  full_name='envoy.service.health.v3.HealthCheckRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node', full_name='envoy.service.health.v3.HealthCheckRequest.node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='capability', full_name='envoy.service.health.v3.HealthCheckRequest.capability', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036/\n-envoy.service.discovery.v2.HealthCheckRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=537,
  serialized_end=710,
)


_ENDPOINTHEALTH = _descriptor.Descriptor(
  name='EndpointHealth',
  full_name='envoy.service.health.v3.EndpointHealth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='envoy.service.health.v3.EndpointHealth.endpoint', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health_status', full_name='envoy.service.health.v3.EndpointHealth.health_status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036+\n)envoy.service.discovery.v2.EndpointHealth',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=713,
  serialized_end=892,
)


_LOCALITYENDPOINTSHEALTH = _descriptor.Descriptor(
  name='LocalityEndpointsHealth',
  full_name='envoy.service.health.v3.LocalityEndpointsHealth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locality', full_name='envoy.service.health.v3.LocalityEndpointsHealth.locality', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoints_health', full_name='envoy.service.health.v3.LocalityEndpointsHealth.endpoints_health', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=895,
  serialized_end=1037,
)


_CLUSTERENDPOINTSHEALTH = _descriptor.Descriptor(
  name='ClusterEndpointsHealth',
  full_name='envoy.service.health.v3.ClusterEndpointsHealth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_name', full_name='envoy.service.health.v3.ClusterEndpointsHealth.cluster_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locality_endpoints_health', full_name='envoy.service.health.v3.ClusterEndpointsHealth.locality_endpoints_health', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1040,
  serialized_end=1171,
)


_ENDPOINTHEALTHRESPONSE = _descriptor.Descriptor(
  name='EndpointHealthResponse',
  full_name='envoy.service.health.v3.EndpointHealthResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoints_health', full_name='envoy.service.health.v3.EndpointHealthResponse.endpoints_health', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_endpoints_health', full_name='envoy.service.health.v3.EndpointHealthResponse.cluster_endpoints_health', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0363\n1envoy.service.discovery.v2.EndpointHealthResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1174,
  serialized_end=1410,
)


_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE = _descriptor.Descriptor(
  name='HealthCheckRequestOrEndpointHealthResponse',
  full_name='envoy.service.health.v3.HealthCheckRequestOrEndpointHealthResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='health_check_request', full_name='envoy.service.health.v3.HealthCheckRequestOrEndpointHealthResponse.health_check_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoint_health_response', full_name='envoy.service.health.v3.HealthCheckRequestOrEndpointHealthResponse.endpoint_health_response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036G\nEenvoy.service.discovery.v2.HealthCheckRequestOrEndpointHealthResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='request_type', full_name='envoy.service.health.v3.HealthCheckRequestOrEndpointHealthResponse.request_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1413,
  serialized_end=1713,
)


_LOCALITYENDPOINTS = _descriptor.Descriptor(
  name='LocalityEndpoints',
  full_name='envoy.service.health.v3.LocalityEndpoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locality', full_name='envoy.service.health.v3.LocalityEndpoints.locality', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoints', full_name='envoy.service.health.v3.LocalityEndpoints.endpoints', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036.\n,envoy.service.discovery.v2.LocalityEndpoints',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1716,
  serialized_end=1893,
)


_CLUSTERHEALTHCHECK = _descriptor.Descriptor(
  name='ClusterHealthCheck',
  full_name='envoy.service.health.v3.ClusterHealthCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_name', full_name='envoy.service.health.v3.ClusterHealthCheck.cluster_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health_checks', full_name='envoy.service.health.v3.ClusterHealthCheck.health_checks', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locality_endpoints', full_name='envoy.service.health.v3.ClusterHealthCheck.locality_endpoints', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transport_socket_matches', full_name='envoy.service.health.v3.ClusterHealthCheck.transport_socket_matches', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036/\n-envoy.service.discovery.v2.ClusterHealthCheck',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1896,
  serialized_end=2211,
)


_HEALTHCHECKSPECIFIER = _descriptor.Descriptor(
  name='HealthCheckSpecifier',
  full_name='envoy.service.health.v3.HealthCheckSpecifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_health_checks', full_name='envoy.service.health.v3.HealthCheckSpecifier.cluster_health_checks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval', full_name='envoy.service.health.v3.HealthCheckSpecifier.interval', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0361\n/envoy.service.discovery.v2.HealthCheckSpecifier',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2214,
  serialized_end=2413,
)

_CAPABILITY.fields_by_name['health_check_protocols'].enum_type = _CAPABILITY_PROTOCOL
_CAPABILITY_PROTOCOL.containing_type = _CAPABILITY
_HEALTHCHECKREQUEST.fields_by_name['node'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._NODE
_HEALTHCHECKREQUEST.fields_by_name['capability'].message_type = _CAPABILITY
_ENDPOINTHEALTH.fields_by_name['endpoint'].message_type = envoy_dot_config_dot_endpoint_dot_v3_dot_endpoint__components__pb2._ENDPOINT
_ENDPOINTHEALTH.fields_by_name['health_status'].enum_type = envoy_dot_config_dot_core_dot_v3_dot_health__check__pb2._HEALTHSTATUS
_LOCALITYENDPOINTSHEALTH.fields_by_name['locality'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._LOCALITY
_LOCALITYENDPOINTSHEALTH.fields_by_name['endpoints_health'].message_type = _ENDPOINTHEALTH
_CLUSTERENDPOINTSHEALTH.fields_by_name['locality_endpoints_health'].message_type = _LOCALITYENDPOINTSHEALTH
_ENDPOINTHEALTHRESPONSE.fields_by_name['endpoints_health'].message_type = _ENDPOINTHEALTH
_ENDPOINTHEALTHRESPONSE.fields_by_name['cluster_endpoints_health'].message_type = _CLUSTERENDPOINTSHEALTH
_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.fields_by_name['health_check_request'].message_type = _HEALTHCHECKREQUEST
_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.fields_by_name['endpoint_health_response'].message_type = _ENDPOINTHEALTHRESPONSE
_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.oneofs_by_name['request_type'].fields.append(
  _HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.fields_by_name['health_check_request'])
_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.fields_by_name['health_check_request'].containing_oneof = _HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.oneofs_by_name['request_type']
_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.oneofs_by_name['request_type'].fields.append(
  _HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.fields_by_name['endpoint_health_response'])
_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.fields_by_name['endpoint_health_response'].containing_oneof = _HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE.oneofs_by_name['request_type']
_LOCALITYENDPOINTS.fields_by_name['locality'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._LOCALITY
_LOCALITYENDPOINTS.fields_by_name['endpoints'].message_type = envoy_dot_config_dot_endpoint_dot_v3_dot_endpoint__components__pb2._ENDPOINT
_CLUSTERHEALTHCHECK.fields_by_name['health_checks'].message_type = envoy_dot_config_dot_core_dot_v3_dot_health__check__pb2._HEALTHCHECK
_CLUSTERHEALTHCHECK.fields_by_name['locality_endpoints'].message_type = _LOCALITYENDPOINTS
_CLUSTERHEALTHCHECK.fields_by_name['transport_socket_matches'].message_type = envoy_dot_config_dot_cluster_dot_v3_dot_cluster__pb2._CLUSTER_TRANSPORTSOCKETMATCH
_HEALTHCHECKSPECIFIER.fields_by_name['cluster_health_checks'].message_type = _CLUSTERHEALTHCHECK
_HEALTHCHECKSPECIFIER.fields_by_name['interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['Capability'] = _CAPABILITY
DESCRIPTOR.message_types_by_name['HealthCheckRequest'] = _HEALTHCHECKREQUEST
DESCRIPTOR.message_types_by_name['EndpointHealth'] = _ENDPOINTHEALTH
DESCRIPTOR.message_types_by_name['LocalityEndpointsHealth'] = _LOCALITYENDPOINTSHEALTH
DESCRIPTOR.message_types_by_name['ClusterEndpointsHealth'] = _CLUSTERENDPOINTSHEALTH
DESCRIPTOR.message_types_by_name['EndpointHealthResponse'] = _ENDPOINTHEALTHRESPONSE
DESCRIPTOR.message_types_by_name['HealthCheckRequestOrEndpointHealthResponse'] = _HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE
DESCRIPTOR.message_types_by_name['LocalityEndpoints'] = _LOCALITYENDPOINTS
DESCRIPTOR.message_types_by_name['ClusterHealthCheck'] = _CLUSTERHEALTHCHECK
DESCRIPTOR.message_types_by_name['HealthCheckSpecifier'] = _HEALTHCHECKSPECIFIER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Capability = _reflection.GeneratedProtocolMessageType('Capability', (_message.Message,), {
  'DESCRIPTOR' : _CAPABILITY,
  '__module__' : 'envoy.service.health.v3.hds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.health.v3.Capability)
  })
_sym_db.RegisterMessage(Capability)

HealthCheckRequest = _reflection.GeneratedProtocolMessageType('HealthCheckRequest', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECKREQUEST,
  '__module__' : 'envoy.service.health.v3.hds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.health.v3.HealthCheckRequest)
  })
_sym_db.RegisterMessage(HealthCheckRequest)

EndpointHealth = _reflection.GeneratedProtocolMessageType('EndpointHealth', (_message.Message,), {
  'DESCRIPTOR' : _ENDPOINTHEALTH,
  '__module__' : 'envoy.service.health.v3.hds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.health.v3.EndpointHealth)
  })
_sym_db.RegisterMessage(EndpointHealth)

LocalityEndpointsHealth = _reflection.GeneratedProtocolMessageType('LocalityEndpointsHealth', (_message.Message,), {
  'DESCRIPTOR' : _LOCALITYENDPOINTSHEALTH,
  '__module__' : 'envoy.service.health.v3.hds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.health.v3.LocalityEndpointsHealth)
  })
_sym_db.RegisterMessage(LocalityEndpointsHealth)

ClusterEndpointsHealth = _reflection.GeneratedProtocolMessageType('ClusterEndpointsHealth', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERENDPOINTSHEALTH,
  '__module__' : 'envoy.service.health.v3.hds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.health.v3.ClusterEndpointsHealth)
  })
_sym_db.RegisterMessage(ClusterEndpointsHealth)

EndpointHealthResponse = _reflection.GeneratedProtocolMessageType('EndpointHealthResponse', (_message.Message,), {
  'DESCRIPTOR' : _ENDPOINTHEALTHRESPONSE,
  '__module__' : 'envoy.service.health.v3.hds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.health.v3.EndpointHealthResponse)
  })
_sym_db.RegisterMessage(EndpointHealthResponse)

HealthCheckRequestOrEndpointHealthResponse = _reflection.GeneratedProtocolMessageType('HealthCheckRequestOrEndpointHealthResponse', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE,
  '__module__' : 'envoy.service.health.v3.hds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.health.v3.HealthCheckRequestOrEndpointHealthResponse)
  })
_sym_db.RegisterMessage(HealthCheckRequestOrEndpointHealthResponse)

LocalityEndpoints = _reflection.GeneratedProtocolMessageType('LocalityEndpoints', (_message.Message,), {
  'DESCRIPTOR' : _LOCALITYENDPOINTS,
  '__module__' : 'envoy.service.health.v3.hds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.health.v3.LocalityEndpoints)
  })
_sym_db.RegisterMessage(LocalityEndpoints)

ClusterHealthCheck = _reflection.GeneratedProtocolMessageType('ClusterHealthCheck', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERHEALTHCHECK,
  '__module__' : 'envoy.service.health.v3.hds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.health.v3.ClusterHealthCheck)
  })
_sym_db.RegisterMessage(ClusterHealthCheck)

HealthCheckSpecifier = _reflection.GeneratedProtocolMessageType('HealthCheckSpecifier', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECKSPECIFIER,
  '__module__' : 'envoy.service.health.v3.hds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.health.v3.HealthCheckSpecifier)
  })
_sym_db.RegisterMessage(HealthCheckSpecifier)


DESCRIPTOR._options = None
_CAPABILITY._options = None
_HEALTHCHECKREQUEST._options = None
_ENDPOINTHEALTH._options = None
_ENDPOINTHEALTHRESPONSE.fields_by_name['endpoints_health']._options = None
_ENDPOINTHEALTHRESPONSE._options = None
_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE._options = None
_LOCALITYENDPOINTS._options = None
_CLUSTERHEALTHCHECK._options = None
_HEALTHCHECKSPECIFIER._options = None

_HEALTHDISCOVERYSERVICE = _descriptor.ServiceDescriptor(
  name='HealthDiscoveryService',
  full_name='envoy.service.health.v3.HealthDiscoveryService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2416,
  serialized_end=2766,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamHealthCheck',
    full_name='envoy.service.health.v3.HealthDiscoveryService.StreamHealthCheck',
    index=0,
    containing_service=None,
    input_type=_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE,
    output_type=_HEALTHCHECKSPECIFIER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchHealthCheck',
    full_name='envoy.service.health.v3.HealthDiscoveryService.FetchHealthCheck',
    index=1,
    containing_service=None,
    input_type=_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE,
    output_type=_HEALTHCHECKSPECIFIER,
    serialized_options=b'\202\323\344\223\002\034\"\032/v3/discovery:health_check\202\323\344\223\002\003:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_HEALTHDISCOVERYSERVICE)

DESCRIPTOR.services_by_name['HealthDiscoveryService'] = _HEALTHDISCOVERYSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/metadata/v3/metadata.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/type/metadata/v3/metadata.proto',
  package='envoy.type.metadata.v3',
  syntax='proto3',
  serialized_options=b'\n$io.envoyproxy.envoy.type.metadata.v3B\rMetadataProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%envoy/type/metadata/v3/metadata.proto\x12\x16\x65nvoy.type.metadata.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x85\x02\n\x0bMetadataKey\x12\x14\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12G\n\x04path\x18\x02 \x03(\x0b\x32/.envoy.type.metadata.v3.MetadataKey.PathSegmentB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1al\n\x0bPathSegment\x12\x16\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00:5\x9a\xc5\x88\x1e\x30\n.envoy.type.metadata.v2.MetadataKey.PathSegmentB\x0e\n\x07segment\x12\x03\xf8\x42\x01:)\x9a\xc5\x88\x1e$\n\"envoy.type.metadata.v2.MetadataKey\"\xb3\x04\n\x0cMetadataKind\x12?\n\x07request\x18\x01 \x01(\x0b\x32,.envoy.type.metadata.v3.MetadataKind.RequestH\x00\x12;\n\x05route\x18\x02 \x01(\x0b\x32*.envoy.type.metadata.v3.MetadataKind.RouteH\x00\x12?\n\x07\x63luster\x18\x03 \x01(\x0b\x32,.envoy.type.metadata.v3.MetadataKind.ClusterH\x00\x12\x39\n\x04host\x18\x04 \x01(\x0b\x32).envoy.type.metadata.v3.MetadataKind.HostH\x00\x1a=\n\x07Request:2\x9a\xc5\x88\x1e-\n+envoy.type.metadata.v2.MetadataKind.Request\x1a\x39\n\x05Route:0\x9a\xc5\x88\x1e+\n)envoy.type.metadata.v2.MetadataKind.Route\x1a=\n\x07\x43luster:2\x9a\xc5\x88\x1e-\n+envoy.type.metadata.v2.MetadataKind.Cluster\x1a\x37\n\x04Host:/\x9a\xc5\x88\x1e*\n(envoy.type.metadata.v2.MetadataKind.Host:*\x9a\xc5\x88\x1e%\n#envoy.type.metadata.v2.MetadataKindB\x0b\n\x04kind\x12\x03\xf8\x42\x01\x42?\n$io.envoyproxy.envoy.type.metadata.v3B\rMetadataProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_METADATAKEY_PATHSEGMENT = _descriptor.Descriptor(
  name='PathSegment',
  full_name='envoy.type.metadata.v3.MetadataKey.PathSegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.type.metadata.v3.MetadataKey.PathSegment.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0360\n.envoy.type.metadata.v2.MetadataKey.PathSegment',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='segment', full_name='envoy.type.metadata.v3.MetadataKey.PathSegment.segment',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=267,
  serialized_end=375,
)

_METADATAKEY = _descriptor.Descriptor(
  name='MetadataKey',
  full_name='envoy.type.metadata.v3.MetadataKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.type.metadata.v3.MetadataKey.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='envoy.type.metadata.v3.MetadataKey.path', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_METADATAKEY_PATHSEGMENT, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036$\n\"envoy.type.metadata.v2.MetadataKey',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=157,
  serialized_end=418,
)


_METADATAKIND_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='envoy.type.metadata.v3.MetadataKind.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036-\n+envoy.type.metadata.v2.MetadataKind.Request',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=687,
  serialized_end=748,
)

_METADATAKIND_ROUTE = _descriptor.Descriptor(
  name='Route',
  full_name='envoy.type.metadata.v3.MetadataKind.Route',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036+\n)envoy.type.metadata.v2.MetadataKind.Route',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=750,
  serialized_end=807,
)

_METADATAKIND_CLUSTER = _descriptor.Descriptor(
  name='Cluster',
  full_name='envoy.type.metadata.v3.MetadataKind.Cluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036-\n+envoy.type.metadata.v2.MetadataKind.Cluster',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=809,
  serialized_end=870,
)

_METADATAKIND_HOST = _descriptor.Descriptor(
  name='Host',
  full_name='envoy.type.metadata.v3.MetadataKind.Host',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036*\n(envoy.type.metadata.v2.MetadataKind.Host',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=872,
  serialized_end=927,
)

_METADATAKIND = _descriptor.Descriptor(
  name='MetadataKind',
  full_name='envoy.type.metadata.v3.MetadataKind',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='envoy.type.metadata.v3.MetadataKind.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route', full_name='envoy.type.metadata.v3.MetadataKind.route', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='envoy.type.metadata.v3.MetadataKind.cluster', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host', full_name='envoy.type.metadata.v3.MetadataKind.host', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_METADATAKIND_REQUEST, _METADATAKIND_ROUTE, _METADATAKIND_CLUSTER, _METADATAKIND_HOST, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036%\n#envoy.type.metadata.v2.MetadataKind',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='envoy.type.metadata.v3.MetadataKind.kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=421,
  serialized_end=984,
)

_METADATAKEY_PATHSEGMENT.containing_type = _METADATAKEY
_METADATAKEY_PATHSEGMENT.oneofs_by_name['segment'].fields.append(
  _METADATAKEY_PATHSEGMENT.fields_by_name['key'])
_METADATAKEY_PATHSEGMENT.fields_by_name['key'].containing_oneof = _METADATAKEY_PATHSEGMENT.oneofs_by_name['segment']
_METADATAKEY.fields_by_name['path'].message_type = _METADATAKEY_PATHSEGMENT
_METADATAKIND_REQUEST.containing_type = _METADATAKIND
_METADATAKIND_ROUTE.containing_type = _METADATAKIND
_METADATAKIND_CLUSTER.containing_type = _METADATAKIND
_METADATAKIND_HOST.containing_type = _METADATAKIND
_METADATAKIND.fields_by_name['request'].message_type = _METADATAKIND_REQUEST
_METADATAKIND.fields_by_name['route'].message_type = _METADATAKIND_ROUTE
_METADATAKIND.fields_by_name['cluster'].message_type = _METADATAKIND_CLUSTER
_METADATAKIND.fields_by_name['host'].message_type = _METADATAKIND_HOST
_METADATAKIND.oneofs_by_name['kind'].fields.append(
  _METADATAKIND.fields_by_name['request'])
_METADATAKIND.fields_by_name['request'].containing_oneof = _METADATAKIND.oneofs_by_name['kind']
_METADATAKIND.oneofs_by_name['kind'].fields.append(
  _METADATAKIND.fields_by_name['route'])
_METADATAKIND.fields_by_name['route'].containing_oneof = _METADATAKIND.oneofs_by_name['kind']
_METADATAKIND.oneofs_by_name['kind'].fields.append(
  _METADATAKIND.fields_by_name['cluster'])
_METADATAKIND.fields_by_name['cluster'].containing_oneof = _METADATAKIND.oneofs_by_name['kind']
_METADATAKIND.oneofs_by_name['kind'].fields.append(
  _METADATAKIND.fields_by_name['host'])
_METADATAKIND.fields_by_name['host'].containing_oneof = _METADATAKIND.oneofs_by_name['kind']
DESCRIPTOR.message_types_by_name['MetadataKey'] = _METADATAKEY
DESCRIPTOR.message_types_by_name['MetadataKind'] = _METADATAKIND
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MetadataKey = _reflection.GeneratedProtocolMessageType('MetadataKey', (_message.Message,), {

  'PathSegment' : _reflection.GeneratedProtocolMessageType('PathSegment', (_message.Message,), {
    'DESCRIPTOR' : _METADATAKEY_PATHSEGMENT,
    '__module__' : 'envoy.type.metadata.v3.metadata_pb2'
    # @@protoc_insertion_point(class_scope:envoy.type.metadata.v3.MetadataKey.PathSegment)
    })
  ,
  'DESCRIPTOR' : _METADATAKEY,
  '__module__' : 'envoy.type.metadata.v3.metadata_pb2'
  # @@protoc_insertion_point(class_scope:envoy.type.metadata.v3.MetadataKey)
  })
_sym_db.RegisterMessage(MetadataKey)
_sym_db.RegisterMessage(MetadataKey.PathSegment)

MetadataKind = _reflection.GeneratedProtocolMessageType('MetadataKind', (_message.Message,), {

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
    'DESCRIPTOR' : _METADATAKIND_REQUEST,
    '__module__' : 'envoy.type.metadata.v3.metadata_pb2'
    # @@protoc_insertion_point(class_scope:envoy.type.metadata.v3.MetadataKind.Request)
    })
  ,

  'Route' : _reflection.GeneratedProtocolMessageType('Route', (_message.Message,), {
    'DESCRIPTOR' : _METADATAKIND_ROUTE,
    '__module__' : 'envoy.type.metadata.v3.metadata_pb2'
    # @@protoc_insertion_point(class_scope:envoy.type.metadata.v3.MetadataKind.Route)
    })
  ,

  'Cluster' : _reflection.GeneratedProtocolMessageType('Cluster', (_message.Message,), {
    'DESCRIPTOR' : _METADATAKIND_CLUSTER,
    '__module__' : 'envoy.type.metadata.v3.metadata_pb2'
    # @@protoc_insertion_point(class_scope:envoy.type.metadata.v3.MetadataKind.Cluster)
    })
  ,

  'Host' : _reflection.GeneratedProtocolMessageType('Host', (_message.Message,), {
    'DESCRIPTOR' : _METADATAKIND_HOST,
    '__module__' : 'envoy.type.metadata.v3.metadata_pb2'
    # @@protoc_insertion_point(class_scope:envoy.type.metadata.v3.MetadataKind.Host)
    })
  ,
  'DESCRIPTOR' : _METADATAKIND,
  '__module__' : 'envoy.type.metadata.v3.metadata_pb2'
  # @@protoc_insertion_point(class_scope:envoy.type.metadata.v3.MetadataKind)
  })
_sym_db.RegisterMessage(MetadataKind)
_sym_db.RegisterMessage(MetadataKind.Request)
_sym_db.RegisterMessage(MetadataKind.Route)
_sym_db.RegisterMessage(MetadataKind.Cluster)
_sym_db.RegisterMessage(MetadataKind.Host)


DESCRIPTOR._options = None
_METADATAKEY_PATHSEGMENT.oneofs_by_name['segment']._options = None
_METADATAKEY_PATHSEGMENT.fields_by_name['key']._options = None
_METADATAKEY_PATHSEGMENT._options = None
_METADATAKEY.fields_by_name['key']._options = None
_METADATAKEY.fields_by_name['path']._options = None
_METADATAKEY._options = None
_METADATAKIND_REQUEST._options = None
_METADATAKIND_ROUTE._options = None
_METADATAKIND_CLUSTER._options = None
_METADATAKIND_HOST._options = None
_METADATAKIND.oneofs_by_name['kind']._options = None
_METADATAKIND._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/accesslog/v4alpha/accesslog.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import base_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2
from envoy.config.route.v4alpha import route_components_pb2 as envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2
from envoy.type.matcher.v4alpha import metadata_pb2 as envoy_dot_type_dot_matcher_dot_v4alpha_dot_metadata__pb2
from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/accesslog/v4alpha/accesslog.proto',
  package='envoy.config.accesslog.v4alpha',
  syntax='proto3',
  serialized_options=b'\n,io.envoyproxy.envoy.config.accesslog.v4alphaB\016AccesslogProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.envoy/config/accesslog/v4alpha/accesslog.proto\x12\x1e\x65nvoy.config.accesslog.v4alpha\x1a$envoy/config/core/v4alpha/base.proto\x1a\x31\x65nvoy/config/route/v4alpha/route_components.proto\x1a)envoy/type/matcher/v4alpha/metadata.proto\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xd1\x01\n\tAccessLog\x12\x0c\n\x04name\x18\x01 \x01(\t\x12?\n\x06\x66ilter\x18\x02 \x01(\x0b\x32/.envoy.config.accesslog.v4alpha.AccessLogFilter\x12,\n\x0ctyped_config\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00:*\x9a\xc5\x88\x1e%\n#envoy.config.accesslog.v3.AccessLogB\r\n\x0b\x63onfig_typeJ\x04\x08\x03\x10\x04R\x06\x63onfig\"\xe9\x07\n\x0f\x41\x63\x63\x65ssLogFilter\x12N\n\x12status_code_filter\x18\x01 \x01(\x0b\x32\x30.envoy.config.accesslog.v4alpha.StatusCodeFilterH\x00\x12I\n\x0f\x64uration_filter\x18\x02 \x01(\x0b\x32..envoy.config.accesslog.v4alpha.DurationFilterH\x00\x12W\n\x17not_health_check_filter\x18\x03 \x01(\x0b\x32\x34.envoy.config.accesslog.v4alpha.NotHealthCheckFilterH\x00\x12K\n\x10traceable_filter\x18\x04 \x01(\x0b\x32/.envoy.config.accesslog.v4alpha.TraceableFilterH\x00\x12G\n\x0eruntime_filter\x18\x05 \x01(\x0b\x32-.envoy.config.accesslog.v4alpha.RuntimeFilterH\x00\x12?\n\nand_filter\x18\x06 \x01(\x0b\x32).envoy.config.accesslog.v4alpha.AndFilterH\x00\x12=\n\tor_filter\x18\x07 \x01(\x0b\x32(.envoy.config.accesslog.v4alpha.OrFilterH\x00\x12\x45\n\rheader_filter\x18\x08 \x01(\x0b\x32,.envoy.config.accesslog.v4alpha.HeaderFilterH\x00\x12R\n\x14response_flag_filter\x18\t \x01(\x0b\x32\x32.envoy.config.accesslog.v4alpha.ResponseFlagFilterH\x00\x12N\n\x12grpc_status_filter\x18\n \x01(\x0b\x32\x30.envoy.config.accesslog.v4alpha.GrpcStatusFilterH\x00\x12K\n\x10\x65xtension_filter\x18\x0b \x01(\x0b\x32/.envoy.config.accesslog.v4alpha.ExtensionFilterH\x00\x12I\n\x0fmetadata_filter\x18\x0c \x01(\x0b\x32..envoy.config.accesslog.v4alpha.MetadataFilterH\x00:0\x9a\xc5\x88\x1e+\n)envoy.config.accesslog.v3.AccessLogFilterB\x17\n\x10\x66ilter_specifier\x12\x03\xf8\x42\x01\"\xe7\x01\n\x10\x43omparisonFilter\x12I\n\x02op\x18\x01 \x01(\x0e\x32\x33.envoy.config.accesslog.v4alpha.ComparisonFilter.OpB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x37\n\x05value\x18\x02 \x01(\x0b\x32(.envoy.config.core.v4alpha.RuntimeUInt32\"\x1c\n\x02Op\x12\x06\n\x02\x45Q\x10\x00\x12\x06\n\x02GE\x10\x01\x12\x06\n\x02LE\x10\x02:1\x9a\xc5\x88\x1e,\n*envoy.config.accesslog.v3.ComparisonFilter\"\x95\x01\n\x10StatusCodeFilter\x12N\n\ncomparison\x18\x01 \x01(\x0b\x32\x30.envoy.config.accesslog.v4alpha.ComparisonFilterB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:1\x9a\xc5\x88\x1e,\n*envoy.config.accesslog.v3.StatusCodeFilter\"\x91\x01\n\x0e\x44urationFilter\x12N\n\ncomparison\x18\x01 \x01(\x0b\x32\x30.envoy.config.accesslog.v4alpha.ComparisonFilterB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:/\x9a\xc5\x88\x1e*\n(envoy.config.accesslog.v3.DurationFilter\"M\n\x14NotHealthCheckFilter:5\x9a\xc5\x88\x1e\x30\n.envoy.config.accesslog.v3.NotHealthCheckFilter\"C\n\x0fTraceableFilter:0\x9a\xc5\x88\x1e+\n)envoy.config.accesslog.v3.TraceableFilter\"\xbc\x01\n\rRuntimeFilter\x12\x1c\n\x0bruntime_key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x39\n\x0fpercent_sampled\x18\x02 \x01(\x0b\x32 .envoy.type.v3.FractionalPercent\x12\"\n\x1ause_independent_randomness\x18\x03 \x01(\x08:.\x9a\xc5\x88\x1e)\n\'envoy.config.accesslog.v3.RuntimeFilter\"\x83\x01\n\tAndFilter\x12J\n\x07\x66ilters\x18\x01 \x03(\x0b\x32/.envoy.config.accesslog.v4alpha.AccessLogFilterB\x08\xfa\x42\x05\x92\x01\x02\x08\x02:*\x9a\xc5\x88\x1e%\n#envoy.config.accesslog.v3.AndFilter\"\x81\x01\n\x08OrFilter\x12J\n\x07\x66ilters\x18\x02 \x03(\x0b\x32/.envoy.config.accesslog.v4alpha.AccessLogFilterB\x08\xfa\x42\x05\x92\x01\x02\x08\x02:)\x9a\xc5\x88\x1e$\n\"envoy.config.accesslog.v3.OrFilter\"\x82\x01\n\x0cHeaderFilter\x12\x43\n\x06header\x18\x01 \x01(\x0b\x32).envoy.config.route.v4alpha.HeaderMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:-\x9a\xc5\x88\x1e(\n&envoy.config.accesslog.v3.HeaderFilter\"\xce\x01\n\x12ResponseFlagFilter\x12\x82\x01\n\x05\x66lags\x18\x01 \x03(\tBs\xfa\x42p\x92\x01m\"kriR\x02LHR\x02UHR\x02UTR\x02LRR\x02URR\x02UFR\x02UCR\x02UOR\x02NRR\x02\x44IR\x02\x46IR\x02RLR\x04UAEXR\x04RLSER\x02\x44\x43R\x03URXR\x02SIR\x02IHR\x03\x44PER\x05UMSDRR\x04RFCFR\x04NFCFR\x02\x44T:3\x9a\xc5\x88\x1e.\n,envoy.config.accesslog.v3.ResponseFlagFilter\"\xeb\x03\n\x10GrpcStatusFilter\x12X\n\x08statuses\x18\x01 \x03(\x0e\x32\x37.envoy.config.accesslog.v4alpha.GrpcStatusFilter.StatusB\r\xfa\x42\n\x92\x01\x07\"\x05\x82\x01\x02\x10\x01\x12\x0f\n\x07\x65xclude\x18\x02 \x01(\x08\"\xb8\x02\n\x06Status\x12\x06\n\x02OK\x10\x00\x12\x0c\n\x08\x43\x41NCELED\x10\x01\x12\x0b\n\x07UNKNOWN\x10\x02\x12\x14\n\x10INVALID_ARGUMENT\x10\x03\x12\x15\n\x11\x44\x45\x41\x44LINE_EXCEEDED\x10\x04\x12\r\n\tNOT_FOUND\x10\x05\x12\x12\n\x0e\x41LREADY_EXISTS\x10\x06\x12\x15\n\x11PERMISSION_DENIED\x10\x07\x12\x16\n\x12RESOURCE_EXHAUSTED\x10\x08\x12\x17\n\x13\x46\x41ILED_PRECONDITION\x10\t\x12\x0b\n\x07\x41\x42ORTED\x10\n\x12\x10\n\x0cOUT_OF_RANGE\x10\x0b\x12\x11\n\rUNIMPLEMENTED\x10\x0c\x12\x0c\n\x08INTERNAL\x10\r\x12\x0f\n\x0bUNAVAILABLE\x10\x0e\x12\r\n\tDATA_LOSS\x10\x0f\x12\x13\n\x0fUNAUTHENTICATED\x10\x10:1\x9a\xc5\x88\x1e,\n*envoy.config.accesslog.v3.GrpcStatusFilter\"\xbb\x01\n\x0eMetadataFilter\x12<\n\x07matcher\x18\x01 \x01(\x0b\x32+.envoy.type.matcher.v4alpha.MetadataMatcher\x12:\n\x16match_if_key_not_found\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue:/\x9a\xc5\x88\x1e*\n(envoy.config.accesslog.v3.MetadataFilter\"\x9c\x01\n\x0f\x45xtensionFilter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00:0\x9a\xc5\x88\x1e+\n)envoy.config.accesslog.v3.ExtensionFilterB\r\n\x0b\x63onfig_typeJ\x04\x08\x02\x10\x03R\x06\x63onfigBH\n,io.envoyproxy.envoy.config.accesslog.v4alphaB\x0e\x41\x63\x63\x65sslogProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2.DESCRIPTOR,envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_v4alpha_dot_metadata__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_percent__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_COMPARISONFILTER_OP = _descriptor.EnumDescriptor(
  name='Op',
  full_name='envoy.config.accesslog.v4alpha.ComparisonFilter.Op',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EQ', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1762,
  serialized_end=1790,
)
_sym_db.RegisterEnumDescriptor(_COMPARISONFILTER_OP)

_GRPCSTATUSFILTER_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='envoy.config.accesslog.v4alpha.GrpcStatusFilter.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CANCELED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ARGUMENT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEADLINE_EXCEEDED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_FOUND', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALREADY_EXISTS', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERMISSION_DENIED', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESOURCE_EXHAUSTED', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED_PRECONDITION', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ABORTED', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUT_OF_RANGE', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIMPLEMENTED', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNAVAILABLE', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATA_LOSS', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNAUTHENTICATED', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3219,
  serialized_end=3531,
)
_sym_db.RegisterEnumDescriptor(_GRPCSTATUSFILTER_STATUS)


_ACCESSLOG = _descriptor.Descriptor(
  name='AccessLog',
  full_name='envoy.config.accesslog.v4alpha.AccessLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.accesslog.v4alpha.AccessLog.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='envoy.config.accesslog.v4alpha.AccessLog.filter', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.config.accesslog.v4alpha.AccessLog.typed_config', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036%\n#envoy.config.accesslog.v3.AccessLog',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.config.accesslog.v4alpha.AccessLog.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=394,
  serialized_end=603,
)


_ACCESSLOGFILTER = _descriptor.Descriptor(
  name='AccessLogFilter',
  full_name='envoy.config.accesslog.v4alpha.AccessLogFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_code_filter', full_name='envoy.config.accesslog.v4alpha.AccessLogFilter.status_code_filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration_filter', full_name='envoy.config.accesslog.v4alpha.AccessLogFilter.duration_filter', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='not_health_check_filter', full_name='envoy.config.accesslog.v4alpha.AccessLogFilter.not_health_check_filter', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traceable_filter', full_name='envoy.config.accesslog.v4alpha.AccessLogFilter.traceable_filter', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime_filter', full_name='envoy.config.accesslog.v4alpha.AccessLogFilter.runtime_filter', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='and_filter', full_name='envoy.config.accesslog.v4alpha.AccessLogFilter.and_filter', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='or_filter', full_name='envoy.config.accesslog.v4alpha.AccessLogFilter.or_filter', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header_filter', full_name='envoy.config.accesslog.v4alpha.AccessLogFilter.header_filter', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_flag_filter', full_name='envoy.config.accesslog.v4alpha.AccessLogFilter.response_flag_filter', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grpc_status_filter', full_name='envoy.config.accesslog.v4alpha.AccessLogFilter.grpc_status_filter', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extension_filter', full_name='envoy.config.accesslog.v4alpha.AccessLogFilter.extension_filter', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_filter', full_name='envoy.config.accesslog.v4alpha.AccessLogFilter.metadata_filter', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036+\n)envoy.config.accesslog.v3.AccessLogFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='filter_specifier', full_name='envoy.config.accesslog.v4alpha.AccessLogFilter.filter_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=606,
  serialized_end=1607,
)


_COMPARISONFILTER = _descriptor.Descriptor(
  name='ComparisonFilter',
  full_name='envoy.config.accesslog.v4alpha.ComparisonFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='op', full_name='envoy.config.accesslog.v4alpha.ComparisonFilter.op', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.config.accesslog.v4alpha.ComparisonFilter.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COMPARISONFILTER_OP,
  ],
  serialized_options=b'\232\305\210\036,\n*envoy.config.accesslog.v3.ComparisonFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1610,
  serialized_end=1841,
)


_STATUSCODEFILTER = _descriptor.Descriptor(
  name='StatusCodeFilter',
  full_name='envoy.config.accesslog.v4alpha.StatusCodeFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='comparison', full_name='envoy.config.accesslog.v4alpha.StatusCodeFilter.comparison', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036,\n*envoy.config.accesslog.v3.StatusCodeFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1844,
  serialized_end=1993,
)


_DURATIONFILTER = _descriptor.Descriptor(
  name='DurationFilter',
  full_name='envoy.config.accesslog.v4alpha.DurationFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='comparison', full_name='envoy.config.accesslog.v4alpha.DurationFilter.comparison', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036*\n(envoy.config.accesslog.v3.DurationFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1996,
  serialized_end=2141,
)


_NOTHEALTHCHECKFILTER = _descriptor.Descriptor(
  name='NotHealthCheckFilter',
  full_name='envoy.config.accesslog.v4alpha.NotHealthCheckFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0360\n.envoy.config.accesslog.v3.NotHealthCheckFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2143,
  serialized_end=2220,
)


_TRACEABLEFILTER = _descriptor.Descriptor(
  name='TraceableFilter',
  full_name='envoy.config.accesslog.v4alpha.TraceableFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036+\n)envoy.config.accesslog.v3.TraceableFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2222,
  serialized_end=2289,
)


_RUNTIMEFILTER = _descriptor.Descriptor(
  name='RuntimeFilter',
  full_name='envoy.config.accesslog.v4alpha.RuntimeFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='runtime_key', full_name='envoy.config.accesslog.v4alpha.RuntimeFilter.runtime_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percent_sampled', full_name='envoy.config.accesslog.v4alpha.RuntimeFilter.percent_sampled', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_independent_randomness', full_name='envoy.config.accesslog.v4alpha.RuntimeFilter.use_independent_randomness', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036)\n\'envoy.config.accesslog.v3.RuntimeFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2292,
  serialized_end=2480,
)


_ANDFILTER = _descriptor.Descriptor(
  name='AndFilter',
  full_name='envoy.config.accesslog.v4alpha.AndFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filters', full_name='envoy.config.accesslog.v4alpha.AndFilter.filters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036%\n#envoy.config.accesslog.v3.AndFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2483,
  serialized_end=2614,
)


_ORFILTER = _descriptor.Descriptor(
  name='OrFilter',
  full_name='envoy.config.accesslog.v4alpha.OrFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filters', full_name='envoy.config.accesslog.v4alpha.OrFilter.filters', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036$\n\"envoy.config.accesslog.v3.OrFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2617,
  serialized_end=2746,
)


_HEADERFILTER = _descriptor.Descriptor(
  name='HeaderFilter',
  full_name='envoy.config.accesslog.v4alpha.HeaderFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='envoy.config.accesslog.v4alpha.HeaderFilter.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036(\n&envoy.config.accesslog.v3.HeaderFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2749,
  serialized_end=2879,
)


_RESPONSEFLAGFILTER = _descriptor.Descriptor(
  name='ResponseFlagFilter',
  full_name='envoy.config.accesslog.v4alpha.ResponseFlagFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flags', full_name='envoy.config.accesslog.v4alpha.ResponseFlagFilter.flags', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372Bp\222\001m\"kriR\002LHR\002UHR\002UTR\002LRR\002URR\002UFR\002UCR\002UOR\002NRR\002DIR\002FIR\002RLR\004UAEXR\004RLSER\002DCR\003URXR\002SIR\002IHR\003DPER\005UMSDRR\004RFCFR\004NFCFR\002DT', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036.\n,envoy.config.accesslog.v3.ResponseFlagFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2882,
  serialized_end=3088,
)


_GRPCSTATUSFILTER = _descriptor.Descriptor(
  name='GrpcStatusFilter',
  full_name='envoy.config.accesslog.v4alpha.GrpcStatusFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='statuses', full_name='envoy.config.accesslog.v4alpha.GrpcStatusFilter.statuses', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\n\222\001\007\"\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exclude', full_name='envoy.config.accesslog.v4alpha.GrpcStatusFilter.exclude', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GRPCSTATUSFILTER_STATUS,
  ],
  serialized_options=b'\232\305\210\036,\n*envoy.config.accesslog.v3.GrpcStatusFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3091,
  serialized_end=3582,
)


_METADATAFILTER = _descriptor.Descriptor(
  name='MetadataFilter',
  full_name='envoy.config.accesslog.v4alpha.MetadataFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='matcher', full_name='envoy.config.accesslog.v4alpha.MetadataFilter.matcher', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='match_if_key_not_found', full_name='envoy.config.accesslog.v4alpha.MetadataFilter.match_if_key_not_found', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036*\n(envoy.config.accesslog.v3.MetadataFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3585,
  serialized_end=3772,
)


_EXTENSIONFILTER = _descriptor.Descriptor(
  name='ExtensionFilter',
  full_name='envoy.config.accesslog.v4alpha.ExtensionFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.accesslog.v4alpha.ExtensionFilter.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.config.accesslog.v4alpha.ExtensionFilter.typed_config', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036+\n)envoy.config.accesslog.v3.ExtensionFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.config.accesslog.v4alpha.ExtensionFilter.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3775,
  serialized_end=3931,
)

_ACCESSLOG.fields_by_name['filter'].message_type = _ACCESSLOGFILTER
_ACCESSLOG.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_ACCESSLOG.oneofs_by_name['config_type'].fields.append(
  _ACCESSLOG.fields_by_name['typed_config'])
_ACCESSLOG.fields_by_name['typed_config'].containing_oneof = _ACCESSLOG.oneofs_by_name['config_type']
_ACCESSLOGFILTER.fields_by_name['status_code_filter'].message_type = _STATUSCODEFILTER
_ACCESSLOGFILTER.fields_by_name['duration_filter'].message_type = _DURATIONFILTER
_ACCESSLOGFILTER.fields_by_name['not_health_check_filter'].message_type = _NOTHEALTHCHECKFILTER
_ACCESSLOGFILTER.fields_by_name['traceable_filter'].message_type = _TRACEABLEFILTER
_ACCESSLOGFILTER.fields_by_name['runtime_filter'].message_type = _RUNTIMEFILTER
_ACCESSLOGFILTER.fields_by_name['and_filter'].message_type = _ANDFILTER
_ACCESSLOGFILTER.fields_by_name['or_filter'].message_type = _ORFILTER
_ACCESSLOGFILTER.fields_by_name['header_filter'].message_type = _HEADERFILTER
_ACCESSLOGFILTER.fields_by_name['response_flag_filter'].message_type = _RESPONSEFLAGFILTER
_ACCESSLOGFILTER.fields_by_name['grpc_status_filter'].message_type = _GRPCSTATUSFILTER
_ACCESSLOGFILTER.fields_by_name['extension_filter'].message_type = _EXTENSIONFILTER
_ACCESSLOGFILTER.fields_by_name['metadata_filter'].message_type = _METADATAFILTER
_ACCESSLOGFILTER.oneofs_by_name['filter_specifier'].fields.append(
  _ACCESSLOGFILTER.fields_by_name['status_code_filter'])
_ACCESSLOGFILTER.fields_by_name['status_code_filter'].containing_oneof = _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']
_ACCESSLOGFILTER.oneofs_by_name['filter_specifier'].fields.append(
  _ACCESSLOGFILTER.fields_by_name['duration_filter'])
_ACCESSLOGFILTER.fields_by_name['duration_filter'].containing_oneof = _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']
_ACCESSLOGFILTER.oneofs_by_name['filter_specifier'].fields.append(
  _ACCESSLOGFILTER.fields_by_name['not_health_check_filter'])
_ACCESSLOGFILTER.fields_by_name['not_health_check_filter'].containing_oneof = _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']
_ACCESSLOGFILTER.oneofs_by_name['filter_specifier'].fields.append(
  _ACCESSLOGFILTER.fields_by_name['traceable_filter'])
_ACCESSLOGFILTER.fields_by_name['traceable_filter'].containing_oneof = _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']
_ACCESSLOGFILTER.oneofs_by_name['filter_specifier'].fields.append(
  _ACCESSLOGFILTER.fields_by_name['runtime_filter'])
_ACCESSLOGFILTER.fields_by_name['runtime_filter'].containing_oneof = _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']
_ACCESSLOGFILTER.oneofs_by_name['filter_specifier'].fields.append(
  _ACCESSLOGFILTER.fields_by_name['and_filter'])
_ACCESSLOGFILTER.fields_by_name['and_filter'].containing_oneof = _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']
_ACCESSLOGFILTER.oneofs_by_name['filter_specifier'].fields.append(
  _ACCESSLOGFILTER.fields_by_name['or_filter'])
_ACCESSLOGFILTER.fields_by_name['or_filter'].containing_oneof = _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']
_ACCESSLOGFILTER.oneofs_by_name['filter_specifier'].fields.append(
  _ACCESSLOGFILTER.fields_by_name['header_filter'])
_ACCESSLOGFILTER.fields_by_name['header_filter'].containing_oneof = _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']
_ACCESSLOGFILTER.oneofs_by_name['filter_specifier'].fields.append(
  _ACCESSLOGFILTER.fields_by_name['response_flag_filter'])
_ACCESSLOGFILTER.fields_by_name['response_flag_filter'].containing_oneof = _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']
_ACCESSLOGFILTER.oneofs_by_name['filter_specifier'].fields.append(
  _ACCESSLOGFILTER.fields_by_name['grpc_status_filter'])
_ACCESSLOGFILTER.fields_by_name['grpc_status_filter'].containing_oneof = _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']
_ACCESSLOGFILTER.oneofs_by_name['filter_specifier'].fields.append(
  _ACCESSLOGFILTER.fields_by_name['extension_filter'])
_ACCESSLOGFILTER.fields_by_name['extension_filter'].containing_oneof = _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']
_ACCESSLOGFILTER.oneofs_by_name['filter_specifier'].fields.append(
  _ACCESSLOGFILTER.fields_by_name['metadata_filter'])
_ACCESSLOGFILTER.fields_by_name['metadata_filter'].containing_oneof = _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']
_COMPARISONFILTER.fields_by_name['op'].enum_type = _COMPARISONFILTER_OP
_COMPARISONFILTER.fields_by_name['value'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._RUNTIMEUINT32
_COMPARISONFILTER_OP.containing_type = _COMPARISONFILTER
_STATUSCODEFILTER.fields_by_name['comparison'].message_type = _COMPARISONFILTER
_DURATIONFILTER.fields_by_name['comparison'].message_type = _COMPARISONFILTER
_RUNTIMEFILTER.fields_by_name['percent_sampled'].message_type = envoy_dot_type_dot_v3_dot_percent__pb2._FRACTIONALPERCENT
_ANDFILTER.fields_by_name['filters'].message_type = _ACCESSLOGFILTER
_ORFILTER.fields_by_name['filters'].message_type = _ACCESSLOGFILTER
_HEADERFILTER.fields_by_name['header'].message_type = envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2._HEADERMATCHER
_GRPCSTATUSFILTER.fields_by_name['statuses'].enum_type = _GRPCSTATUSFILTER_STATUS
_GRPCSTATUSFILTER_STATUS.containing_type = _GRPCSTATUSFILTER
_METADATAFILTER.fields_by_name['matcher'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_metadata__pb2._METADATAMATCHER
_METADATAFILTER.fields_by_name['match_if_key_not_found'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_EXTENSIONFILTER.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_EXTENSIONFILTER.oneofs_by_name['config_type'].fields.append(
  _EXTENSIONFILTER.fields_by_name['typed_config'])
_EXTENSIONFILTER.fields_by_name['typed_config'].containing_oneof = _EXTENSIONFILTER.oneofs_by_name['config_type']
DESCRIPTOR.message_types_by_name['AccessLog'] = _ACCESSLOG
DESCRIPTOR.message_types_by_name['AccessLogFilter'] = _ACCESSLOGFILTER
DESCRIPTOR.message_types_by_name['ComparisonFilter'] = _COMPARISONFILTER
DESCRIPTOR.message_types_by_name['StatusCodeFilter'] = _STATUSCODEFILTER
DESCRIPTOR.message_types_by_name['DurationFilter'] = _DURATIONFILTER
DESCRIPTOR.message_types_by_name['NotHealthCheckFilter'] = _NOTHEALTHCHECKFILTER
DESCRIPTOR.message_types_by_name['TraceableFilter'] = _TRACEABLEFILTER
DESCRIPTOR.message_types_by_name['RuntimeFilter'] = _RUNTIMEFILTER
DESCRIPTOR.message_types_by_name['AndFilter'] = _ANDFILTER
DESCRIPTOR.message_types_by_name['OrFilter'] = _ORFILTER
DESCRIPTOR.message_types_by_name['HeaderFilter'] = _HEADERFILTER
DESCRIPTOR.message_types_by_name['ResponseFlagFilter'] = _RESPONSEFLAGFILTER
DESCRIPTOR.message_types_by_name['GrpcStatusFilter'] = _GRPCSTATUSFILTER
DESCRIPTOR.message_types_by_name['MetadataFilter'] = _METADATAFILTER
DESCRIPTOR.message_types_by_name['ExtensionFilter'] = _EXTENSIONFILTER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AccessLog = _reflection.GeneratedProtocolMessageType('AccessLog', (_message.Message,), {
  'DESCRIPTOR' : _ACCESSLOG,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.AccessLog)
  })
_sym_db.RegisterMessage(AccessLog)

AccessLogFilter = _reflection.GeneratedProtocolMessageType('AccessLogFilter', (_message.Message,), {
  'DESCRIPTOR' : _ACCESSLOGFILTER,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.AccessLogFilter)
  })
_sym_db.RegisterMessage(AccessLogFilter)

ComparisonFilter = _reflection.GeneratedProtocolMessageType('ComparisonFilter', (_message.Message,), {
  'DESCRIPTOR' : _COMPARISONFILTER,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.ComparisonFilter)
  })
_sym_db.RegisterMessage(ComparisonFilter)

StatusCodeFilter = _reflection.GeneratedProtocolMessageType('StatusCodeFilter', (_message.Message,), {
  'DESCRIPTOR' : _STATUSCODEFILTER,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.StatusCodeFilter)
  })
_sym_db.RegisterMessage(StatusCodeFilter)

DurationFilter = _reflection.GeneratedProtocolMessageType('DurationFilter', (_message.Message,), {
  'DESCRIPTOR' : _DURATIONFILTER,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.DurationFilter)
  })
_sym_db.RegisterMessage(DurationFilter)

NotHealthCheckFilter = _reflection.GeneratedProtocolMessageType('NotHealthCheckFilter', (_message.Message,), {
  'DESCRIPTOR' : _NOTHEALTHCHECKFILTER,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.NotHealthCheckFilter)
  })
_sym_db.RegisterMessage(NotHealthCheckFilter)

TraceableFilter = _reflection.GeneratedProtocolMessageType('TraceableFilter', (_message.Message,), {
  'DESCRIPTOR' : _TRACEABLEFILTER,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.TraceableFilter)
  })
_sym_db.RegisterMessage(TraceableFilter)

RuntimeFilter = _reflection.GeneratedProtocolMessageType('RuntimeFilter', (_message.Message,), {
  'DESCRIPTOR' : _RUNTIMEFILTER,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.RuntimeFilter)
  })
_sym_db.RegisterMessage(RuntimeFilter)

AndFilter = _reflection.GeneratedProtocolMessageType('AndFilter', (_message.Message,), {
  'DESCRIPTOR' : _ANDFILTER,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.AndFilter)
  })
_sym_db.RegisterMessage(AndFilter)

OrFilter = _reflection.GeneratedProtocolMessageType('OrFilter', (_message.Message,), {
  'DESCRIPTOR' : _ORFILTER,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.OrFilter)
  })
_sym_db.RegisterMessage(OrFilter)

HeaderFilter = _reflection.GeneratedProtocolMessageType('HeaderFilter', (_message.Message,), {
  'DESCRIPTOR' : _HEADERFILTER,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.HeaderFilter)
  })
_sym_db.RegisterMessage(HeaderFilter)

ResponseFlagFilter = _reflection.GeneratedProtocolMessageType('ResponseFlagFilter', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEFLAGFILTER,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.ResponseFlagFilter)
  })
_sym_db.RegisterMessage(ResponseFlagFilter)

GrpcStatusFilter = _reflection.GeneratedProtocolMessageType('GrpcStatusFilter', (_message.Message,), {
  'DESCRIPTOR' : _GRPCSTATUSFILTER,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.GrpcStatusFilter)
  })
_sym_db.RegisterMessage(GrpcStatusFilter)

MetadataFilter = _reflection.GeneratedProtocolMessageType('MetadataFilter', (_message.Message,), {
  'DESCRIPTOR' : _METADATAFILTER,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.MetadataFilter)
  })
_sym_db.RegisterMessage(MetadataFilter)

ExtensionFilter = _reflection.GeneratedProtocolMessageType('ExtensionFilter', (_message.Message,), {
  'DESCRIPTOR' : _EXTENSIONFILTER,
  '__module__' : 'envoy.config.accesslog.v4alpha.accesslog_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.accesslog.v4alpha.ExtensionFilter)
  })
_sym_db.RegisterMessage(ExtensionFilter)


DESCRIPTOR._options = None
_ACCESSLOG._options = None
_ACCESSLOGFILTER.oneofs_by_name['filter_specifier']._options = None
_ACCESSLOGFILTER._options = None
_COMPARISONFILTER.fields_by_name['op']._options = None
_COMPARISONFILTER._options = None
_STATUSCODEFILTER.fields_by_name['comparison']._options = None
_STATUSCODEFILTER._options = None
_DURATIONFILTER.fields_by_name['comparison']._options = None
_DURATIONFILTER._options = None
_NOTHEALTHCHECKFILTER._options = None
_TRACEABLEFILTER._options = None
_RUNTIMEFILTER.fields_by_name['runtime_key']._options = None
_RUNTIMEFILTER._options = None
_ANDFILTER.fields_by_name['filters']._options = None
_ANDFILTER._options = None
_ORFILTER.fields_by_name['filters']._options = None
_ORFILTER._options = None
_HEADERFILTER.fields_by_name['header']._options = None
_HEADERFILTER._options = None
_RESPONSEFLAGFILTER.fields_by_name['flags']._options = None
_RESPONSEFLAGFILTER._options = None
_GRPCSTATUSFILTER.fields_by_name['statuses']._options = None
_GRPCSTATUSFILTER._options = None
_METADATAFILTER._options = None
_EXTENSIONFILTER._options = None
# @@protoc_insertion_point(module_scope)
